@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2006,2007,2009 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2006-2015 -- leonerd@leonerd.org.uk
 
 package Time::HiRes::Value;
 
@@ -13,7 +13,7 @@ use Carp;
 use Time::HiRes qw( gettimeofday );
 use POSIX qw( floor );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Since we use this number quite a lot, make a constant out of it to avoid
 # typoes
@@ -21,12 +21,12 @@ use constant USEC => 1_000_000;
 
 =head1 NAME
 
-C<Time::HiRes::Value> - a class representing a time value or interval in exact
+C<Time::HiRes::Value> - represent a time value or interval in exact
 microseconds
 
 =head1 DESCRIPTION
 
-The C<Time::HiRes> module allows perl to access the system's clock to
+The L<Time::HiRes> module allows perl to access the system's clock to
 microsecond accuracy. However, floating point numbers are not suitable for
 manipulating such time values, as rounding errors creep in to calculations
 performed on floating-point representations of UNIX time. This class provides
@@ -330,10 +330,6 @@ sub cmp
           $self->[1] <=> $other->[1];
 }
 
-1;
-
-__END__
-
 =head1 SEE ALSO
 
 =over 4
@@ -347,3 +343,7 @@ L<Time::HiRes> - Obtain system timers in resolution greater than 1 second
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
+0x55AA;
